*desc_010308.do
capture log close
log using "U:\papers and projects\earnings associations\do\desc_010308.log", replace
set more 1
clear
program drop _all
set mem 500M

set matsize 3000


#delimit cr



   use "U:\papers and projects\earnings associations\dta\topcode.dta", clear



     ***This part deflates the weights so that the original
     ***sample size is maintained


        bysort y: egen double sumwgt = sum(WEIGHT)
        bysort y: gen N = _N


        bysort y: gen double deflate = N/sumwgt



        *preserve original weight variables
         rename WEIGHT oweight

        bysort y: gen double WEIGHT = oweight*deflate


   keep if y > 1967



***Percentage of income that is wage and salary income by year.
***For numbers in text in "Measurement" section.


   *Earnings of H&W as a percentage of H&W's income
    gen pHWinc = Te/Ti*100

   *Earnings of H&W as a percentage of total household income
    gen pFinc = Te/FT*100

   *drop outliers from summary stats
    summarize pHWinc if pHWinc > -500 & pHWinc < 500 [aw=WEIGHT]
    table y if pHWinc > -500 & pHWinc < 500 [w=oweight], c(mean pHWinc min pHWinc max pHWinc)

   *drop outliers from summary stats
    summarize pFinc if pFinc > -500 & pFinc < 500 [aw=WEIGHT]
    table y if pFinc > -500 & pFinc < 500 [w=oweight], c(mean pFinc min pFinc max pFinc)



***Year categories***

    #delimit ;
    recode y  1968/1971 = 1968 1972/1975 = 1972 1976/1979 = 1976 1980/1983 = 1980
              1984/1987 = 1984 1988/1991 = 1988 1992/1995 = 1992 1996/1999 = 1996
              2000/2003 = 2000 2004/2006 = 2004;
    #delimit cr



rename Te T



*********************************************************
* MEASURES OF EARNINGS INEQUALITY AMONG MARRIED COUPLES *
*********************************************************

             preserve

               #delimit ;


               collapse (p10)  p10T=T
                        (p15)  p15T=T
                        (p20)  p20T=T
                        (p25)  p25T=T
                        (p30)  p30T=T
                        (p40)  p40T=T
                        (p45)  p45T=T
                        (p50)  p50T=T
                        (p55)  p55T=T
                        (p60)  p60T=T
                        (p70)  p70T=T
                        (p75)  p75T=T
                        (p80)  p80T=T
                        (p85)  p85T=T
                        (p90)  p90T=T [w=oweight] , by(y) ;

               #delimit cr

                  foreach num of numlist 90 85 75 55 50 25 15 10 {
                   replace p`num'T = p`num'T/1000
                  }

                  foreach num of numlist 90 85 75 55 50 25 15 10 {
                   quietly gen  pchg`num' =  ((p`num'T - p`num'T[1])/p`num'T[1])*100
                  }

                  lab var pchg90 "90th"
                  lab var pchg75 "75th"
                  lab var pchg50 "median"
                  lab var pchg25 "25th"
                  lab var pchg10 "10th"

                  #delimit ;
                  twoway connected pchg90 pchg75 pchg50 pchg25 pchg10 y, c(l)
                  scheme(s1color)
                  msymbol(S + X D Th)
                  msize(medium medium medsmall medsmall) ysc(r(-20 60))  ylabel(-20(10)60, grid)
                  clpattern(llll) clcolor(gs0 gs0 gs0 gs0 gs0) mcolor(gs0 gs0 gs0 gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
                  xlabel(#15)   title(" ", size(medlarge) color(gs0)) sub(" ")
                  ytitle("% Change since 1967") xtitle("Year")
                  title("Percentage Change in Real Wage and Salary Income by Percentile") sub("Husbands and Wives Age 22-55")
                  note("SOURCE: March Current Population Survey (CPS).")
                   ;

                 #delimit cr

                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_010308_1.wmf, replace


                 **Comparisons with median.

                  sort y

                  foreach num of numlist 90 75 25 10 {
                   quietly gen  p`num'_50 =  ((p`num'T/p50T)/(p`num'T[1]/p50T[1]))*100
                  }

              restore
              preserve

        #delimit ;


               collapse (p20)  p20T=T
                        (p50)  p50T=T
                        (p60)  p60T=T /*51-60*/
                        (p80)  p80T=T
                        (p90)  p90T=T [iw=oweight] , by(y) ;

        #delimit cr

                   quietly gen  p80_20 =  ((p80T/p20T)/(p80T[1]/p20T[1]))*100
                   quietly gen  p50_20 =  ((p50T/p20T)/(p50T[1]/p20T[1]))*100
                   quietly gen  p80_50 =  ((p80T/p50T)/(p80T[1]/p50T[1]))*100

                   quietly gen  f80_20 =  (p80T/p20T)
                   quietly gen  f50_20 =  (p50T/p20T)
                   quietly gen  f80_50 =  (p80T/p50T)


                  lab var p80_20 "80/20 ratio"
                  lab var p80_50 "80/50 ratio"
                  lab var p50_20 "50/20 ratio"




                  *estimates of change in ratios using individual-level data for Supplementary Table B1.

                   list f80_20 f50_20 f80_50 y






                  #delimit ;
              twoway connected p80_20 p80_50 p50_20 y, c(l)
                                              mlcolor(gs0 gs0 gs0 gs0 gs0)
                                              mfcolor(gs12 gs0 gs0 gs0 gs0)
                                              clcolor(gs0 gs4 gs0 gs4 gs0)
                                              msize(medium medium medium medium medium)
                                              msymbol(s Oh t X o)
                                              ysc(r(60 140))  ylabel(60(10)140, labsize(*.9) labgap(.01))
                                              yline(100, lcolor(black))
                                              l1title("Index 1967-1971=100", size(*.9))
                                              scheme(s1color)
                                              graphregion(fcolor(gs16)) plotregion(style(none))
                                              title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1968 `" " 1967-" "1970" "' 1972 `" " 1971-" "1974" "'  1976 `" " 1975-" "1978" "'
                         1980 `" " 1979-" "1982" "' 1984 `" " 1983-" "1986" "'  1988 `" " 1987-" "1991" "'
                         1992 `" " 1991-" "1994" "' 1996 `" " 1995-" "1998" "'  2000 `" " 1999-" "2002" "'  2004 `" " 2003-" "2005" "' , labsize(*.9))
                                              xtitle("Year") legend(rows(2))
                                              ;
                 #delimit cr


                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_010308_2.wmf, replace fontface(garamond)


        ***Color

                  #delimit ;
              twoway connected p80_20 p80_50 p50_20 y, c(l)
                                            mcolor(blue red lime purple brown gs4)
                                            clcolor(blue red lime purple brown gs4)
                                              msize(medlarge medlarge medlarge medlarge medlarge medlarge)
                                              msymbol(s O t X o)
                                              msize(medium medium medium medium medium)
                                              ysc(r(60 140))  ylabel(60(10)140, labsize(*.9) labgap(.01))
                                              yline(100, lcolor(black))
                                              l1title("Index 1967-1971=100", size(*.9))
                                              scheme(s1color)
                                              graphregion(fcolor(gs16)) plotregion(style(none))
                                              title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1968 `" " 1967-" "1970" "' 1972 `" " 1971-" "1974" "'  1976 `" " 1975-" "1978" "'
                         1980 `" " 1979-" "1982" "' 1984 `" " 1983-" "1986" "'  1988 `" " 1987-" "1991" "'
                         1992 `" " 1991-" "1994" "' 1996 `" " 1995-" "1998" "'  2000 `" " 1999-" "2002" "'  2004 `" " 2003-" "2005" "', labsize(*.9))
                                              xtitle("Year") legend(rows(2))
                                              ;
                 #delimit cr


                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_010308_3.wmf, replace

                 **Comparisons with each other.




                 list p80_20 p50_20 p80_50 y if y == 2001
                 list p80_20 p50_20 p80_50 y if y == 1996
                 list f80_20 f50_20 f80_50 y if y == 1968
                 list f80_20 f50_20 f80_50 y if y == 2001


                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_010308_4.wmf, replace

                 keep p* y
                 sort y
                 tempfile ratios
                 save `ratios'

       **SAVE data set with the values of the percentiles for total-earnings


         sort y
         keep y p20T p50T p90T p80T p60T
         tempfile tps
         save `tps'



            restore



        *****************
        *  CV BY SOURCE *
        *****************


              ************
              * EVERYONE *
              ************



              *The corr is the same whether I use fweight or aweights

              foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
               quietly corr H W [aw=oweight] if y == `num'
               quietly gen r`num' = r(rho)
              }


               gen wW = W if W > 0


              *the standard deviation differs slightly using aweights. Use fweights
              *here.

               foreach var of varlist H W wW T {
                 foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {

                   quietly summarize `var' [fw=oweight] if y == `num'
                   scalar def  V`var'`num'  = (r(sd))
                   scalar def  M`var'`num' = (r(mean))
                   scalar def CV`var'`num' = V`var'`num'/M`var'`num'

               }
               }


             **Numbers for Supplementary Table B1
               display CVT1968
               display CVT2004


               #delimit ;

               *OBSERVED CHANGE IN CV ;

               foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {  ;

               scalar def a = MH`num'/MT`num' ;
               scalar def b = MW`num'/MT`num' ;

               scalar def const_CV2`num' = (a^2*CVH`num'^2) +
                                         (b^2*CVW`num'^2) +
                                         (2*r`num'*a*b*CVH`num'*CVW`num') ;

               gen CVf`num' = sqrt(const_CV2`num') ;


               } ;


               display CVf1968 ;
               display CVf2004 ;




                 *COUNTERFACTUAL 1: no change in the correlation btwn spouses' wages ;

                 forvalues i = 1968(4)2004 { ;

                 scalar def a = MH`i'/MT`i' ;
                 scalar def b = MW`i'/MT`i' ;

                 scalar def const_CV2`i' = (a^2*CVH`i'^2) +
                                           (b^2*CVW`i'^2) +
                                           (2*r1968*a*b*CVH`i'*CVW`i') ;

                 gen cf1_CVf`i' = sqrt(const_CV2`i') ;


                 } ;


             **Numbers for Supplementary table B1 "CV, less changes in correlation" ;
               display cf1_CVf1968 ;
               display cf1_CVf2004 ;



               #delimit cr


               forvalues j = 1968(4)2004 {
                 gen pchh`j' = (CVH`j'/CVH1968)*100
                 gen pchw`j' = (CVW`j'/CVW1968)*100
                 gen pchww`j'= (CVwW`j'/CVwW1968)*100
                 gen pchf`j' = (CVT`j'/CVT1968)*100
                 gen pcf1`j' = (cf1_CVf`j'/cf1_CVf1968)*100
               }



              preserve

              keep in 1
              keep pch* pcf1*
              gen id = 1
              reshape long pchh pchw pchww pchf pcf1, i(id) j(y)


              lab var pchh  "Husbands"
              lab var pchw  "Wives"
              lab var pchww "Wives (non-zero-earnings)"
              lab var pchf  "Couples"
              lab var pcf1  "Couples, r(H,W) = 1967"


              sort y
              merge y using `ratios'




                  #delimit ;
              twoway connected pchh pchw pchf y, c(l)
                                              mlcolor(gs0 gs0 gs0 gs0 gs0)
                                              mfcolor(gs12 gs0 gs0 gs0 gs0)
                                              clcolor(gs0 gs4 gs0 gs4 gs0)
                                              msize(medium medium medium medium medium)
                                              msymbol(s Oh t X o)
                                              ysc(r(60 140))  ylabel(60(10)140, labsize(*.9) labgap(.01))
                                              yline(100, lcolor(black))
                                              l1title("Index 1967-1971=100", size(*.9))
                                              scheme(s1color)
                                              graphregion(fcolor(gs16)) plotregion(style(none))
                                              title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1968 `" " 1967-" "1970" "' 1972 `" " 1971-" "1974" "'  1976 `" " 1975-" "1978" "'
                         1980 `" " 1979-" "1982" "' 1984 `" " 1983-" "1986" "'  1988 `" " 1987-" "1991" "'
                         1992 `" " 1991-" "1994" "' 1996 `" " 1995-" "1998" "'  2000 `" " 1999-" "2002" "'  2004 `" " 2003-" "2005" "', labsize(*.9))
                                              xtitle("Year") legend(rows(2))
                                              ;
                 #delimit cr


                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_010308_5.wmf, replace fontface(garamond)



              **Color

                  #delimit ;
              twoway connected pchh pchw pchf y, c(l)
                                            mcolor(blue red lime gs4)
                                            clcolor(blue red lime gs4)
                                              msize(medlarge medlarge medlarge medlarge medlarge medlarge)
                                              msymbol(s O t X o)
                                              msymbol(s O t X o)
                                              ysc(r(60 140))  ylabel(60(10)140, labsize(*.9) labgap(.01))
                                              yline(100, lcolor(black))
                                              l1title("Index 1967-1971=100", size(*.9))
                                              scheme(s1color)
                                              graphregion(fcolor(gs16)) plotregion(style(none))
                                              title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1968 `" " 1967-" "1970" "' 1972 `" " 1971-" "1974" "'  1976 `" " 1975-" "1978" "'
                         1980 `" " 1979-" "1982" "' 1984 `" " 1983-" "1986" "'  1988 `" " 1987-" "1991" "'
                         1992 `" " 1991-" "1994" "' 1996 `" " 1995-" "1998" "'  2000 `" " 1999-" "2002" "'  2004 `" " 2003-" "2005" "', labsize(*.9))
                                              xtitle("Year") legend(rows(2))
                                              ;
                 #delimit cr


                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_010308_6.wmf, replace


              **Color

                  #delimit ;
              twoway connected pchh pchw pchf pcf1 y, c(l)
                                            mcolor(blue red lime purple gs4)
                                            clcolor(blue red lime purple gs4)
                                              msize(medlarge medlarge medlarge medlarge medlarge medlarge)
                                              msymbol(s O t X o)
                                              msymbol(s O t X o)
                                              ysc(r(60 140))  ylabel(60(10)140, labsize(*.9) labgap(.01))
                                              yline(100, lcolor(black))
                                              l1title("Index 1967-1971=100", size(*.9))
                                              scheme(s1color)
                                              graphregion(fcolor(gs16)) plotregion(style(none))
                                              title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1968 `" " 1967-" "1970" "' 1972 `" " 1971-" "1974" "'  1976 `" " 1975-" "1978" "'
                         1980 `" " 1979-" "1982" "' 1984 `" " 1983-" "1986" "'  1988 `" " 1987-" "1991" "'
                         1992 `" " 1991-" "1994" "' 1996 `" " 1995-" "1998" "'  2000 `" " 1999-" "2002" "'  2004 `" " 2003-" "2005" "', labsize(*.9))
                                              xtitle("Year") legend(rows(2))
                                              ;
                 #delimit cr


                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_010308_7.wmf, replace




    *recode years to medians

    #delimit ;
    recode y  1968=1969.5 1972=1973.5 1976=1977.5 1980=1981.5
              1984=1985.5 1988=1989.5 1992=1993.5 1996=1997.5
              2000=2001.5 2004=2005;
    #delimit cr

              lab var pchf "CV"

                  #delimit ;
              twoway connected p80_20 p50_20 p80_50 pchf y, c(l)
                                              mlcolor(gs0 gs0 gs0 gs0 gs0)
                                              mfcolor(gs12 gs0 gs0 gs0 gs0)
                                              clcolor(gs0 gs4 gs0 gs4 gs0)
                                              msize(medium medium medium medium medium)
                                              msymbol(s Oh t X o)
                                              ysc(r(100 140))  ylabel(100(10)150, labsize(*.9) labgap(.01))
                                              yline(100, lcolor(black))
                                              l1title("Index 1967-1970=100", size(*.9))
                                              scheme(s1color)
                                              graphregion(fcolor(gs16)) plotregion(style(none))
                                              title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                              xtitle("Year") legend(rows(2))
                                              ;
                 #delimit cr


                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_010308_8.wmf, replace fontface(garamond)




              **Color



                  #delimit ;
              twoway connected p80_20 p50_20 p80_50 pchf y, c(l)
                                            mcolor(blue red lime purple gs4)
                                            clcolor(blue red lime purple gs4)
                                              msize(medlarge medlarge medlarge medlarge medlarge medlarge)
                                              msymbol(s O t X o)
                                              msymbol(s O t X o)
                                              ysc(r(100 140))  ylabel(100(10)150, labsize(*.9) labgap(.01))
                                              yline(100, lcolor(black))
                                              l1title("Index 1967-1971=100", size(*.9))
                                              scheme(s1color)
                                              graphregion(fcolor(gs16)) plotregion(style(none))
                                              title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                              xtitle("Year") legend(rows(2))
                                              ;
                 #delimit cr


                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_010308_9.wmf, replace


         *Numbers for discussion of Figure 1
          list pchh pchw pchf pcf1 p80_20 p50_20 p80_50 y if y == 2005

          list pchh pchw pchf y if y == 1997.5
          list pchh pchw pchf y if y == 1993.5

            restore





***************
* CORRELATION *
***************



      *I use aweights here.  The same answer is obtained using fweights.


         foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
          quietly corr W H if W ~= 0 & H ~= 0 & y == `num' [aw=oweight]
          quietly gen rwork`num' = r(rho)
           quietly corr W H if                             y == `num' [aw=oweight]
           quietly gen rall`num' = r(rho)
         }


         preserve

         keep in 1
         collapse rwork* rall*

         gen id = 1
         reshape long rwork rall, i(id) j(y)

         lab var rwork "Dual-Earner Couples"
         lab var rall  "All Couples"




      **************
      ***FIGURE 2***
      **************


    *recode years to medians

    #delimit ;
    recode y  1968=1969.5 1972=1973.5 1976=1977.5 1980=1981.5
              1984=1985.5 1988=1989.5 1992=1993.5 1996=1997.5
              2000=2001.5 2004=2005;
    #delimit cr


                #delimit ;
            twoway connected   rwork   rall  y, c(l)
                                            mlcolor(gs0 gs0 gs0 gs0)
                                            mfcolor(gs0 gs0 gs0 gs0)
                                            clcolor(gs0 gs0 gs0 gs0)
                                            msize(*1.2 medium)
                                            msymbol(sh O)
                                            ysc(r(-.1 .25))  ylabel(-.1(.05).25, labsize(*.9) labgap(.01))
                                            yline(0, lcolor(black))
                                            l1title("Correlation", size(*.9))
                                            scheme(s1color)
                                            graphregion(fcolor(gs16)) plotregion(style(none))
                                            title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                            xtitle("Year")
                                            ;
               #delimit cr


               cd "U:\papers and projects\earnings associations\graphs"

         graph export desc_010308_10.wmf, replace fontface(Arial)
         graph export desc_010308_10.eps, replace fontface(Arial)


        *Numbers for discussion of Figure 2
         list rwork rall y



      **Color
                #delimit ;
            twoway connected rall rwork  y, c(l)
                                            mlcolor(blue  red   gs0 gs0)
                                            mfcolor(blue  red    gs0 gs0)
                                            clcolor(blue  red   gs0 gs0)
                                            msize(medlarge  medlarge   medium medium)
                                            msymbol(/*s Oh*/ t O)
                                            ysc(r(-.1 .25))  ylabel(-.1(.05).25, labgap(.01))
                                            yline(0, lcolor(black))
                                            ytitle("Correlation")
                                            scheme(s1color)
                                            graphregion(fcolor(gs16)) plotregion(style(none))
                                            title("", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                            xtitle("Year")
                                            ;
               #delimit cr


               cd "U:\papers and projects\earnings associations\graphs"

         graph export desc_010308_11.wmf, replace


               list y rwork rall



      restore





*********************************
* CHANGES IN HUSBAND'S EARNINGS *
*********************************


     preserve

       #delimit ;


       collapse (p10)  p10H=H
                (p20)  p20H=H
                (p25)  p25H=H
                (p30)  p30H=H
                (p40)  p40H=H
                (p50)  p50H=H
                (p60)  p60H=H
                (p70)  p70H=H
                (p75)  p75H=H
                (p80)  p80H=H
                (p90)  p90H=H [w=oweight] if H > 0, by(y) ;

       #delimit cr


          foreach num of numlist 90 75 50 25 10 {
           quietly gen  pchg`num' =  ((p`num'H - p`num'H[1])/p`num'H[1])*100
          }

          lab var pchg90 "90th"
          lab var pchg75 "75th"
          lab var pchg50 "median"
          lab var pchg25 "25th"
          lab var pchg10 "10th"

          #delimit ;
          twoway connected pchg90 pchg75 pchg50 pchg25 pchg10 y, c(l)
          scheme(s1color)
          msymbol(S + X D Th)
          msize(medium medium medsmall medsmall) ysc(r(-20 60))  ylabel(-20(10)60, grid)
          clpattern(llll) clcolor(gs0 gs0 gs0 gs0 gs0) mcolor(gs0 gs0 gs0 gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
          xlabel(#15)   title(" ", size(medlarge) color(gs0)) sub(" ")
          ytitle("% Change since 1967") xtitle("Year")
          title("Percentage Change in Real Wage and Salary Income by Income Percentile") sub("Husbands Age 21-55")
          note("SOURCE: March Current Population Survey (CPS).")
           ;

         #delimit cr

         cd "U:\papers and projects\earnings associations\graphs"
         graph export desc_010308_12.wmf, replace


         **Comparisons with median.


          foreach num of numlist 90 75 25 10 {
           quietly gen  p`num'_50 =  ((p`num'H/p50H)/(p`num'H[1]/p50H[1]))*100
          }


          lab var p90_50 "90th/Median"
          lab var p75_50 "75th/Median"
          lab var p25_50 "25th/Median"
          lab var p10_50 "10th/Median"

          #delimit ;
          twoway connected p90_50 p75_50 p25_50 p10_50 y, c(l)
          scheme(s1color)
          msymbol(S + X D Th)
          msize(medium medium medsmall medsmall)   ysc(r(80 130))  ylabel(80(20)130, grid)
          clpattern(llll) clcolor(gs0 gs0 gs0 gs0 gs0) mcolor(gs0 gs0 gs0 gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
          xlabel(#15)   title(" ", size(medlarge) color(gs0)) sub(" ")
          ytitle("Index 1967-1971=100") xtitle("Year")
          title("Inequality Among Wage and Salarly Workers") sub("Husbands Age 21-55")
          note("SOURCE: March Current Population Survey (CPS).")
           ;

         #delimit cr

         cd "U:\papers and projects\earnings associations\graphs"
         graph export desc_010308_13.wmf, replace


         **Comparisons with each other.


           quietly gen  p90_10 =  ((p90H/p10H)/(p90H[1]/p10H[1]))*100
           quietly gen  p50_10 =  ((p50H/p10H)/(p50H[1]/p10H[1]))*100


          lab var p90_10 "90th/10th"
          lab var p50_10 "Median/10th"

          #delimit ;
          twoway connected p90_50 p90_10 p50_10 y, c(l)
          scheme(s1color)
          msymbol(S + X D Th)
          msize(medium medium medsmall medsmall)   ysc(r(80 130))  ylabel(80(20)130, grid)
          clpattern(llll) clcolor(gs0 gs0 gs0 gs0 gs0) mcolor(gs0 gs0 gs0 gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
          xlabel(#15)   title(" ", size(medlarge) color(gs0)) sub(" ")
          ytitle("Index 1967-1971=100") xtitle("Year")
          title("Inequality Among Wage and Salarly Workers") sub("Husbands Age 21-55")
          note("SOURCE: March Current Population Survey (CPS).")
           ;

         #delimit cr

         cd "U:\papers and projects\earnings associations\graphs"
         graph export desc_010308_14.wmf, replace


       sort y

       tempfile hps
       save `hps'

      restore

      **merge percentiles onto individual-level file

      sort y
      merge y using `hps'
      drop _merge

      drop r???? CVf* cf1* pch*

      **Assign everyone to a percentile.

       foreach pre in H {
          quietly gen     `pre'p = 10  if `pre' <= p10`pre' & `pre' > 0
          quietly replace `pre'p = 100 if `pre'  > p90`pre'
           forvalues j = 20(10)90 {
            local k = `j' - 10
             quietly replace `pre'p = `j' if `pre' <= p`j'`pre' & `pre' > p`k'`pre'
           }
       }



      **Merge on total percentages too

      sort y
      merge y using `tps'
      drop _merge

      **Assign everyone to a percentile.

       /*
       foreach pre in T {
          quietly gen     `pre'p = 20  if `pre' <= p20`pre' & `pre' > 0
          quietly replace `pre'p = 50 if `pre' <= p80`pre' & `pre' > p20`pre'
         *quietly replace `pre'p = 60 if `pre' <= p60`pre' & `pre' > p50`pre'
          quietly replace `pre'p = 90 if             `pre' > p80`pre'
       }
      */

       foreach pre in T {
          quietly gen     `pre'p = 0 if `pre' <= p50`pre'
          quietly replace `pre'p = 1 if `pre' >  p50`pre'
       }



   ***************************************************************
   ** FIGURE 4:  % Working Wives by Husbands' Earnings Decile  **
   ***************************************************************


     **Indicator for whether wife works.
       gen wwork = (W ~= 0)
     **Indicator for whether husband works.
       gen hwork = (H ~= 0)

     **Indicator for dual earner couples.
       gen dual = (W ~= 0 & H ~= 0)
       gen neither = (W == 0 & H == 0)


    preserve


     collapse (mean) wwork [aw=oweight], by(Hp y)

      replace wwork = wwork*100

      reshape wide wwork, i(Hp) j(y)

       lab var wwork1968 "1967-1970"
       lab var wwork1972 "1971-1974"
       lab var wwork1976 "1975-1978"
       lab var wwork1980 "1979-1982"
       lab var wwork1984 "1983-1986"
       lab var wwork1988 "1987-1990"
       lab var wwork1992 "1991-1994"
       lab var wwork1996 "1995-1998"
       lab var wwork2000 "1999-2002"
       lab var wwork2004 "2003-2005"


          #delimit ;
       twoway connected wwork1968 wwork1976 wwork1984 wwork1992 wwork2000 Hp, c(l)
                                      mlcolor(gs0 gs0 gs0 gs0 gs0)
                                      mfcolor(gs0 gs0 gs0 gs0 gs0)
                                      clcolor(gs0 gs0 gs0 gs0 gs0)
                                      msize(*1.2 medium medium *1.18 medium)
                                      msymbol(sh O T dh s)
                                      ysc(r(0 100))  ylabel(0(10)100, labsize(*.9) labgap(.01))
                                      l1title("Percentage", size(*.9))
                                      scheme(s1color)
                                      graphregion(fcolor(gs16)) plotregion(style(none))
                                      title(" ", size(medlarge) color(gs0)) sub(" ")
                                      xlabel(10 "1-10" 20 "11-20" 30 "21-30" 40 "31-40" 50 "41-50" 60 "51-60" 70 "61-70" 80 "71-80"
                                      90 "81-90" 100 "91-100", labsize(*.9))
                                      xtitle("Husbands' Earnings Percentile", size(*.9)) legend(rows(2))
                                      ;
         #delimit cr

         cd "U:\papers and projects\earnings associations\graphs"
         graph export desc_010308_15.wmf, replace fontface(Arial)
         graph export desc_010308_15.eps, replace fontface(Arial)


      restore


    preserve


     *If you're in decile 90, your percentile is 81-90. Therefore the groups are
     *Low-earning = 1-20
     *Middle-earning  = 21-80
     *High-earning = 81-100

     gen     H3 = 1 if Hp <= 20
     replace H3 = 2 if Hp >  20 & Hp < 90
     replace H3 = 3 if Hp >= 90

     collapse (median) W [iw=oweight] if W > 0 & H>0, by(H3 y)

      replace W = W/1000

      reshape wide W, i(y) j(H3)

       lab var W1 "Low-earning husbands"
       lab var W2 "Middle-earning husbands"
       lab var W3 "High-earning husbands"


      gen W1p = W1/W1[1]*100
      gen W2p = W2/W2[1]*100
      gen W3p = W3/W3[1]*100


    *recode years to medians

    #delimit ;
    recode y  1968=1969.5 1972=1973.5 1976=1977.5 1980=1981.5
              1984=1985.5 1988=1989.5 1992=1993.5 1996=1997.5
              2000=2001.5 2004=2005;
    #delimit cr

          #delimit ;
       twoway connected W1 W2 W3 y, c(l)
                                      mlcolor(gs0 gs0 gs0 gs0 gs0)
                                      mfcolor(gs12 gs0 gs0 gs0 gs0)
                                      clcolor(gs0 gs4 gs0 gs4 gs0)
                                      msize(medium medium medium medium medium)
                                      msymbol(s Oh t X o)
/*                                    ysc(r(0 100))  ylabel(0(10)100, labsize(*.9) labgap(.01))*/
                                      l1title("2005 Dollars/1000", size(*.9))
                                      scheme(s1color)
                                      graphregion(fcolor(gs16)) plotregion(style(none))
                                      title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                            xtitle("Year", size(*.9)) legend(rows(2) order(3 2 1))
                                      ;
         #delimit cr

         cd "U:\papers and projects\earnings associations\graphs"
         graph export desc_010308_16.wmf, replace fontface(garamond)


   ***************************************************************
   ** FIGURE 3:  Change in Wives' Earnings by Husbands' Earnings**
   ***************************************************************



       lab var W1p "Low-earning husbands"
       lab var W2p "Middle-earning husbands"
       lab var W3p "High-earning husbands"

          #delimit ;
       twoway connected W1p W2p W3p y, c(l)
                                      mlcolor(gs0 gs0 gs0 gs0)
                                      mfcolor(gs0 gs0 gs0 gs0)
                                      clcolor(gs0 gs0 gs0 gs0)
                                      msize(medium *1.18 medium)
                                      msymbol(T dh O)
                                              yline(100, lcolor(black))
                                              l1title("Index 1967-1971=100", size(*.9))
                                      scheme(s1color)
                                      graphregion(fcolor(gs16)) plotregion(style(none))
                                      title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                            xtitle("Year", size(*.9)) legend(rows(2) order(3 2 1))
                                      ;
         #delimit cr

         cd "U:\papers and projects\earnings associations\graphs"
         graph export desc_010308_17.wmf, replace fontface(Arial)
         graph export desc_010308_17.eps, replace fontface(Arial)


      restore

    preserve


     gen     H3 = 1 if Hp <= 20
     replace H3 = 2 if Hp >  20 & Hp < 90
     replace H3 = 3 if Hp >= 90

     collapse (mean) wwork [iw=oweight] , by(H3 y)

      replace wwork = wwork*100


   ***************************************************************
   ** FIGURE 5:  % Working Wives by Husbands' Earnings         **
   ***************************************************************

      reshape wide wwork, i(y) j(H3)

       lab var wwork1 "Low-earning husbands"
       lab var wwork2 "Middle-earning husbands"
       lab var wwork3 "High-earning husbands"


    *recode years to medians

    #delimit ;
    recode y  1968=1969.5 1972=1973.5 1976=1977.5 1980=1981.5
              1984=1985.5 1988=1989.5 1992=1993.5 1996=1997.5
              2000=2001.5 2004=2005;
    #delimit cr

          #delimit ;
       twoway connected wwork1 wwork2 wwork3 y, c(l)
                                      mlcolor(gs0 gs0 gs0 gs0)
                                      mfcolor(gs0 gs0 gs0 gs0)
                                      clcolor(gs0 gs0 gs0 gs0)
                                      msize(medium *1.18 medium)
                                      msymbol(T dh O)
                                      ysc(r(0 100))  ylabel(0(10)100, labsize(*.9) labgap(.01))
                                      l1title("Percentage", size(*.9))
                                      scheme(s1color)
                                      graphregion(fcolor(gs16)) plotregion(style(none))
                                      title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                            xtitle("Year", size(*.9)) legend(rows(2) order(3 2 1))
                                      ;
         #delimit cr

         cd "U:\papers and projects\earnings associations\graphs"
         graph export desc_010308_18.wmf, replace fontface(Arial)
         graph export desc_010308_18.eps, replace fontface(Arial)


      list wwork* y

      restore



     **************
     ***FIGURE 6***
     **************


     preserve

     collapse (mean) hwork wwork dual neither [aw=oweight], by(y)

      replace hwork = hwork*100
      replace wwork = wwork*100
      replace dual = dual*100
      replace neither = neither*100

       label var hwork "Husbands"
       label var wwork " "
       label var dual " "

    *recode years to medians

    #delimit ;
    recode y  1968=1969.5 1972=1973.5 1976=1977.5 1980=1981.5
              1984=1985.5 1988=1989.5 1992=1993.5 1996=1997.5
              2000=2001.5 2004=2005;
    #delimit cr

          #delimit ;
      twoway connected /*hwork*/ dual /*wwork*/ y, c(l)
                                      mlcolor(gs0 gs0 gs0 gs0)
                                      mfcolor(gs0 gs0 gs0 gs0)
                                      clcolor(gs0 gs0 gs0 gs0)
                                      msize(*1.2 medium)
                                      msymbol(sh O)
                                      ysc(r(0 100)) ylabel(0(10)100, labsize(*.9) labgap(.01))
                                      l1title("Percentage", size(*.9))
                                      scheme(s1color)
                                      graphregion(fcolor(gs16)) plotregion(style(none))
                                      title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                      xtitle("Year")
                                      ;
         #delimit cr


         cd "U:\papers and projects\earnings associations\graphs"
         graph export desc_010308_19.wmf, replace fontface(Arial)
         graph export desc_010308_19.eps, replace fontface(Arial)


      **Numbers for discussion of Figure 6 in text
        list hwork wwork dual y

        reg dual wwork


   restore


    preserve


     gen     H3 = 1 if Hp <= 20
     replace H3 = 2 if Hp >  20 & Hp < 90
     replace H3 = 3 if Hp >= 90

     collapse (mean) dual [iw=oweight] , by(H3 y)


      replace dual = dual*100

      reshape wide dual, i(y) j(H3)

       lab var dual1 "Low-earning husbands"
       lab var dual2 "Middle-earning husbands"
       lab var dual3 "High-earning husbands"


    *recode years to medians

    #delimit ;
    recode y  1968=1969.5 1972=1973.5 1976=1977.5 1980=1981.5
              1984=1985.5 1988=1989.5 1992=1993.5 1996=1997.5
              2000=2001.5 2004=2005;
    #delimit cr

          #delimit ;
       twoway connected dual1 dual2 dual3 y, c(l)
                                      mlcolor(gs0 gs0 gs0 gs0 gs0)
                                      mfcolor(gs12 gs0 gs0 gs0 gs0)
                                      clcolor(gs0 gs4 gs0 gs4 gs0)
                                      msize(medium medium medium medium medium)
                                      msymbol(s Oh t X o)
/*                                    ysc(r(0 100))  ylabel(0(10)100, labsize(*.9) labgap(.01))*/
                                      l1title("Percentage", size(*.9))
                                      scheme(s1color)
                                      graphregion(fcolor(gs16)) plotregion(style(none))
                                      title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                            xtitle("Year", size(*.9)) legend(rows(2))
                                      ;
         #delimit cr

         cd "U:\papers and projects\earnings associations\graphs"
         graph export desc_010308_20.wmf, replace fontface(garamond)

    restore

    preserve


     collapse (mean) dual [iw=oweight] , by(Tp y)


      replace dual = dual*100

      reshape wide dual, i(y) j(Tp)

       lab var dual0 "<= Median-earning couples"
       lab var dual1 "> Median-earning couples"


    *recode years to medians

    #delimit ;
    recode y  1968=1969.5 1972=1973.5 1976=1977.5 1980=1981.5
              1984=1985.5 1988=1989.5 1992=1993.5 1996=1997.5
              2000=2001.5 2004=2005;
    #delimit cr

          #delimit ;
       twoway connected dual0 dual1 y, c(l)
                                      mlcolor(gs0 gs0 gs0 gs0 gs0)
                                      mfcolor(gs12 gs0 gs0 gs0 gs0)
                                      clcolor(gs0 gs4 gs0 gs4 gs0)
                                      msize(medium medium medium medium medium)
                                      msymbol(s Oh t X o)
/*                                    ysc(r(0 100))  ylabel(0(10)100, labsize(*.9) labgap(.01))*/
                                      l1title("Percentage", size(*.9))
                                      scheme(s1color)
                                      graphregion(fcolor(gs16)) plotregion(style(none))
                                      title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                            xtitle("Year", size(*.9)) legend(rows(2))
                                      ;
         #delimit cr

         cd "U:\papers and projects\earnings associations\graphs"
         graph export desc_010308_21.wmf, replace fontface(garamond)

